pub enum EventMaskParseError {
TooManyBitsSet(EventMask),
QueueOverflow,
}Expand description
An error that occured from parsing an raw event mask
Variants
TooManyBitsSet(EventMask)
More than one bit repesenting the event type was set
QueueOverflow
The event is a signal that the kernels event queue overflowed