pub enum EventKind {
Access,
Attrib,
CloseWrite,
CloseNowrite,
Create,
Delete,
DeleteSelf,
Modify,
MoveSelf,
MovedFrom,
MovedTo,
Open,
}Expand description
Represents the type of inotify event
Variants
Access
Attrib
Metadata changed—for example, permissions (e.g.,
chmod(2)), timestamps (e.g., utimensat(2)), extended
attributes (setxattr(2)), link count (since Linux
2.6.25; e.g., for the target of link(2) and for
unlink(2)), and user/group ID (e.g., chown(2))
CloseWrite
File opened for writing was closed
CloseNowrite
File or directory not opened for writing was closed
Create
File/directory created in watched directory (e.g.,
open(2) O_CREAT, mkdir(2), link(2), symlink(2), bind(2)
on a UNIX domain socket)
Delete
File/directory deleted from watched directory
DeleteSelf
Watched file/directory was itself deleted. (This event
also occurs if an object is moved to another
filesystem, since mv(1) in effect copies the file to
the other filesystem and then deletes it from the
original filesystem.)
Modify
File was modified (e.g., write(2), truncate(2))
MoveSelf
Watched file/directory was itself moved
MovedFrom
Generated for the directory containing the old filename when a file is renamed
MovedTo
Generated for the directory containing the new filename when a file is renamed
Open
File or directory was opened
Implementations
Sourceimpl EventKind
impl EventKind
const BITFLAG_ENUM_MAP: &[(EventMask, EventKind)]
Sourcepub fn from_raw_event_mask(
mask: EventMask,
) -> Result<Option<Self>, EventMaskParseError>
pub fn from_raw_event_mask( mask: EventMask, ) -> Result<Option<Self>, EventMaskParseError>
Parse the auxiliary flags from a raw event mask